==> parcel-bundler-vue-1.6.3.tgz: package/lib/assets/VueAsset.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _get2 = require('babel-runtime/helpers/get');

var _get3 = _interopRequireDefault(_get2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var dbg = require('debug')('parcel:VueAsset');
var JSAsset = require('./JSAsset');
var compiler = require('../transforms/vue');

var VueAsset = function (_JSAsset) {
  (0, _inherits3.default)(VueAsset, _JSAsset);

  function VueAsset() {
    (0, _classCallCheck3.default)(this, VueAsset);
    return (0, _possibleConstructorReturn3.default)(this, (VueAsset.__proto__ || (0, _getPrototypeOf2.default)(VueAsset)).apply(this, arguments));
  }

  (0, _createClass3.default)(VueAsset, [{
    key: 'install',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                return _context.abrupt('return', [
                //       {name: 'vue', dev: false},
                //       {name: 'vuex', dev: false},
                //       {name: 'vue-router', dev: false},
                //       {name: 'vuex-router-sync', dev: false},
                // {name: 'vue-hot-reload-api', dev: false},
                { name: 'vue-template-compiler', dev: false }, {
                  name: 'vue-component-compiler@https://github.com/shawwn/vue-component-compiler#parcel-vue-component-compiler',
                  dev: false
                }]);

              case 1:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function install() {
        return _ref.apply(this, arguments);
      }

      return install;
    }()
  }, {
    key: 'parse',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(code) {
        var _this2 = this;

        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                dbg('parse', code);
                // let vueconfig = await config.load(this.name, ['vue.config.json']);
                this.vue = compiler(code, this.name);
                dbg('parse:vue', code);
                this.contents = this.vue.code;
                this.vue.dependencies.forEach(function (v, k) {
                  var contents = v.code;
                  dbg('parse:vue:write', [k, contents]);
                  _this2.addDependency(k, { contents: contents });
                });
                _context2.next = 7;
                return (0, _get3.default)(VueAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(VueAsset.prototype), 'parse', this).call(this, this.contents);

              case 7:
                return _context2.abrupt('return', _context2.sent);

              case 8:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function parse(_x) {
        return _ref2.apply(this, arguments);
      }

      return parse;
    }()
  }]);
  return VueAsset;
}(JSAsset);

module.exports = VueAsset;

==> parcel-bundler-vue-2.0.0.tgz: package/lib/assets/VueAsset.js <==
'use strict';

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var _getPrototypeOf = require('babel-runtime/core-js/object/get-prototype-of');

var _getPrototypeOf2 = _interopRequireDefault(_getPrototypeOf);

var _classCallCheck2 = require('babel-runtime/helpers/classCallCheck');

var _classCallCheck3 = _interopRequireDefault(_classCallCheck2);

var _createClass2 = require('babel-runtime/helpers/createClass');

var _createClass3 = _interopRequireDefault(_createClass2);

var _possibleConstructorReturn2 = require('babel-runtime/helpers/possibleConstructorReturn');

var _possibleConstructorReturn3 = _interopRequireDefault(_possibleConstructorReturn2);

var _get2 = require('babel-runtime/helpers/get');

var _get3 = _interopRequireDefault(_get2);

var _inherits2 = require('babel-runtime/helpers/inherits');

var _inherits3 = _interopRequireDefault(_inherits2);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var dbg = require('debug')('parcel:VueAsset');
var JSAsset = require('./JSAsset');
var compiler = require('../transforms/vue');

var VueAsset = function (_JSAsset) {
  (0, _inherits3.default)(VueAsset, _JSAsset);

  function VueAsset() {
    (0, _classCallCheck3.default)(this, VueAsset);
    return (0, _possibleConstructorReturn3.default)(this, (VueAsset.__proto__ || (0, _getPrototypeOf2.default)(VueAsset)).apply(this, arguments));
  }

  (0, _createClass3.default)(VueAsset, [{
    key: 'install',
    value: function () {
      var _ref = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee() {
        return _regenerator2.default.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                return _context.abrupt('return', [{ name: 'vue', dev: false }, { name: 'vuex', dev: false }, { name: 'vue-router', dev: false }, { name: 'vuex-router-sync', dev: false },
                // {name: 'vue-hot-reload-api', dev: false},
                { name: 'vue-template-compiler', dev: false }, {
                  name: 'vue-component-compiler@https://github.com/shawwn/vue-component-compiler#parcel-vue-component-compiler',
                  dev: false
                }]);

              case 1:
              case 'end':
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function install() {
        return _ref.apply(this, arguments);
      }

      return install;
    }()
  }, {
    key: 'parse',
    value: function () {
      var _ref2 = (0, _asyncToGenerator3.default)( /*#__PURE__*/_regenerator2.default.mark(function _callee2(code) {
        var _this2 = this;

        return _regenerator2.default.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                dbg('parse', code);
                // let vueconfig = await config.load(this.name, ['vue.config.json']);
                this.vue = compiler(code, this.name);
                dbg('parse:vue', code);
                this.contents = this.vue.code;
                this.vue.dependencies.forEach(function (v, k) {
                  var contents = v.code;
                  dbg('parse:vue:write', [k, contents]);
                  _this2.addDependency(k, { contents: contents });
                });
                _context2.next = 7;
                return (0, _get3.default)(VueAsset.prototype.__proto__ || (0, _getPrototypeOf2.default)(VueAsset.prototype), 'parse', this).call(this, this.contents);

              case 7:
                return _context2.abrupt('return', _context2.sent);

              case 8:
              case 'end':
                return _context2.stop();
            }
          }
        }, _callee2, this);
      }));

      function parse(_x) {
        return _ref2.apply(this, arguments);
      }

      return parse;
    }()
  }]);
  return VueAsset;
}(JSAsset);

module.exports = VueAsset;
